<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Registers your tab in the addon  settings page
 *
 * @since 1.0.0
 * @return void
 */
function qsm_addon_qsm_url_parameters_register_addon_settings_tabs() {
	global $mlwQuizMasterNext;
	if ( ! is_null( $mlwQuizMasterNext ) && ! is_null( $mlwQuizMasterNext->pluginHelper ) && method_exists( $mlwQuizMasterNext->pluginHelper, 'register_quiz_settings_tabs' ) ) {
		$mlwQuizMasterNext->pluginHelper->register_addon_settings_tab( 'URL Parameters', 'qsm_addon_qsm_url_parameters_addon_settings_tabs_content' );
	}
}

/**
 * Generates the content for your addon settings tab
 *
 * @since 1.0.0
 * @return void
 */
function qsm_addon_qsm_url_parameters_addon_settings_tabs_content() {
	global $mlwQuizMasterNext;
	// If nonce is correct, update settings from passed input.
	if ( isset( $_POST['url_parameters_nonce'] ) && wp_verify_nonce( $_POST['url_parameters_nonce'], 'url_parameters' ) ) {
		// Load previous license key.
		$settings	 = get_option( 'qsm_addon_url_parameters_settings', '' );
		$license	 = isset( $settings['license_key'] ) ? trim( $settings['license_key'] ) : '';

		$saved_license	 = isset( $_POST['license_key'] ) ? sanitize_text_field( wp_unslash( $_POST['license_key'] ) ) : '';
		$new_settings	 = array( 'license_key' => $saved_license );
		// Checks to see if the license key has changed.
		if ( $license !== $saved_license ) {
			$activation = QSM_license::activate( $saved_license, 'URL Parameters' );
			if ( 'success' == $activation['status'] ) {
				$mlwQuizMasterNext->alertManager->newAlert( $activation['message'], 'success' );
			} else {
				$new_settings['license_key'] = '';
				$mlwQuizMasterNext->alertManager->newAlert( $activation['message'], 'error' );
			}
			// If previous license key was entered.
			$deactivation = QSM_license::deactivate( $license, 'URL Parameters' );
		}
		update_option( 'qsm_addon_url_parameters_settings', $new_settings );
		$mlwQuizMasterNext->alertManager->newAlert( 'Your settings has been saved successfully!', 'success' );
	}
	$addon_data = wp_parse_args( get_option( 'qsm_addon_url_parameters_settings', array() ), array( 'license_key' => '' ) );
	$mlwQuizMasterNext->alertManager->showAlerts();
	?>
	<form action="" method="post">
		<table class="form-table" style="width: 100%;">
			<tr valign="top">
				<th scope="row"><label for="license_key"><?php _e( 'Addon License Key', 'qsm-flashcards' ); ?></label></th>
				<td><input type="text" name="license_key" id="license_key" value="<?php echo esc_attr( $addon_data['license_key'] ); ?>"></td>
			</tr>
		</table>
		<?php wp_nonce_field( 'url_parameters', 'url_parameters_nonce' ); ?>
		<button class="button-primary"><?php _e( 'Save Changes', 'qsm-flashcards' ); ?></button>
	</form>
	<?php
}
